@@ -1,29 +1,38 @@
 #' Reads a triple-s XML (asc) data file, as specified by the triple-s XML standard.
 #'
-#' This function reads and parses a .sss XML metadata file as well as its associated .asc data file. The .sss standard defines a standard survey structure
+#' This function reads and parses a `.sss` XML metadata file as well as its associated `.asc` data file. The sss standard defines a standard survey structure.
 #'
 #' @param sssFilename Character string: name of .sss file containing the survey metadata
 #' @param ascFilename Character string: name of .asc file containing survey data
-#' @param sep Character vector defining the string that separates question and subquestion labels, e.g. \code{c("Q_1", "Q_2")}
+#' @param sep Character vector defining the string that separates question and subquestion labels, e.g. `c("Q_1", "Q_2")`
 #' @return
 #' A data frame with one element (column) for each variable in the data set.
-#' The data.frame contains several attributes:
 #' 
-#' \describe{
-#' \item{variable.labels}{a named list of value labels with one element per variable, either NULL or a names character vector}
-#' }
+#' The data.frame contains several attributes:
+#'  * `variable.labels`: a named list of value labels with one element per variable, either NULL or a named character vector
+#'  * `label.table`: a named list with one element per question. Every element is a named character strings, that contains the label codes for that question.
+#' 
 #' @keywords read
+#' @importFrom stats setNames
 #' @references http://www.triple-s.org/
 #' @export 
-#' @examples
-#' # Not executed
-#' # read.sss("sample.sss, sample.asc")
+#' @example inst/examples/example-read-sss.R
 read.sss <- function(sssFilename, ascFilename, sep = "_"){
+  assert_that(is.character(sssFilename))
+  assert_that(file.exists(sssFilename))
+  
+  
+  if(missing(ascFilename) || is.null(ascFilename)) {
+    ext <- getSSSformat(sssFilename)
+    ascFilename <- guessAsc(sssFilename, ext = ext)
+  }
+  
+  assert_that(is.character(ascFilename))
+  assert_that(file.exists(ascFilename))
+  
   message("Reading SSS metadata")
   switch(class(sssFilename),
          "character" = {
-           if(!file.exists(sssFilename)) stop("File doesn't exist: ", sssFilename)
-           if(!file.exists(ascFilename)) stop("File doesn't exist: ", ascFilename)
            doc <- readSSSmetadata(sssFilename)
            sss <- parseSSSmetadata(doc)
          }, 
@@ -36,8 +45,7 @@ read.sss <- function(sssFilename, ascFilename, sep = "_"){
   sss$variables <- splitSSS(sss$variable, sep)
   
   message("Reading SSS data")
-  #asc <- readSSSdata(ascFilename)
-  
+
   ascWidth <- sss$variables$colWidth
   
   types <- c(single = "character",
@@ -49,8 +57,10 @@ read.sss <- function(sssFilename, ascFilename, sep = "_"){
               date = "Date"
               )
   ascType <- types[sss$variables$type]
-  ascType[sss$variables$type == "multiple"] <- "numeric"
-  ascType[sss$variables$type == "multiple" & sss$variables$subfields > 0] <- "character"
+  idx <- sss$variables$type == "multiple"
+  ascType[idx] <- "numeric"
+  idx <- sss$variables$type == "multiple" & sss$variables$subfields > 0
+  ascType[idx] <- "character"
   
   ascNames <- sss$variables$name
   
@@ -73,6 +83,10 @@ read.sss <- function(sssFilename, ascFilename, sep = "_"){
   )
   dat <- changeValues(sss, dat)
   dat <- addQtext(sss, dat)
+  labelTabelData <- split(sss$codes, f = sss$codes$ident)
+  labelTable <- lapply(labelTabelData, 
+                       function(x)setNames(x[["code"]], x[["codevalues"]])
+                       )
+  attr(dat, "label.table") <- labelTable
   dat
 }
-
